@@ -1,7 +1,7 @@
 import logging
 
 
-def logs_file_setup(file: str, level=logging.INFO):
+def logs_file_setup(level=logging.INFO):
     import os
     import sys
     import time
@@ -10,7 +10,7 @@ def logs_file_setup(file: str, level=logging.INFO):
     today = date.today()
     timestamp = str(time.time()).replace('.', '')
     logs_dir = f"logs/logs-{today.strftime('%d-%m-%Y')}"
-    logs_file = f'{logs_dir}/{os.path.splitext(os.path.basename(file))[0]}-{timestamp}.log'
+    logs_file = f'{logs_dir}/{timestamp}.log'
     os.makedirs(logs_dir, exist_ok=True)
     logging.basicConfig(filename=logs_file, filemode='w+', level=level)
     handler = logging.StreamHandler(sys.stdout)
@@ -18,4 +18,4 @@ def logs_file_setup(file: str, level=logging.INFO):
 
 
 if __name__ == '__main__':
-    logs_file_setup(__file__, logging.DEBUG)
+    logs_file_setup(logging.DEBUG)
